package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.R;
import cn.wisenergy.mapper.*;
import cn.wisenergy.model.app.Actives;
import cn.wisenergy.model.app.UserData;
import cn.wisenergy.model.dto.UserDto;
import cn.wisenergy.model.dto.UsersInfoDto;
import cn.wisenergy.service.Manager.UserDataManger;
import cn.wisenergy.service.app.UserDataService;
import org.apache.shiro.util.CollectionUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * @author 86187
 */
@Service
public class UserDataServiceImpl implements UserDataService {
    @Resource
    private UsersMapper usersMapper;

    @Resource
    private ActivesMapper activesMapper;

    @Resource
    private UserRechargeMapper userRechargeMapper;

    @Resource
    private UserWithdrawsMapper withdrawsMapper;

    @Resource
    private UsdtOrderDetailsMapper orderDetailsMapper;

    @Resource
    private UserDataManger userDataManger;


    @Override
    public R<Boolean> addBatch() {
        //获取所有用户数据
        List<UserDto> userDtos = usersMapper.getAllUserData();
        if (CollectionUtils.isEmpty(userDtos)) {
            return R.ok(1, false);
        }

        UserData userData = new UserData();

        List<UserData> list = new ArrayList<>();
        for (UserDto userDto : userDtos) {
            Long userId = userDto.getUserId();

            //1、用户基本信息
            userData.setUserId(userDto.getUserId());
            userData.setPhone(userDto.getPhone());
            userData.setRank(userDto.getRank());

            //2、用户身份、电话信息
            Actives actives = activesMapper.getByUserId(userId);
            if (null != actives) {
                userData.setIdNumber(actives.getIdNumber());
                userData.setRealName(actives.getRealName());
            }

            //3、向下最深层级层级数、伞下人员总和
            UsersInfoDto userInfoDto = usersMapper.getLevelAndTotal(userId);
            if (null != userInfoDto) {
                if (null != userInfoDto.getBottom()) {
                    userData.setBottom(userInfoDto.getBottom() - userDto.getRank());
                }
                userData.setTotalPeople(userInfoDto.getTotalPeople());
            }

            //4、充值总额
            Double totalRecharge = userRechargeMapper.getTotalRecharge(userId);
            if (null != totalRecharge) {
                userData.setTotalRecharge(totalRecharge);
            }

            //5、提现总额
            Double totalWithdrawal = withdrawsMapper.getTotalWithdrawal(userId);
            if (null != totalWithdrawal) {
                userData.setTotalWithdrawal(totalWithdrawal);
            }

            //6、otc卖出总额
            Double buyTotal = orderDetailsMapper.getBuyTotal(userId);
            if (null != buyTotal) {
                userData.setBuyTotal(buyTotal);
            }

            //7、otc买入总额
            Double saleTotal = orderDetailsMapper.getSaleTotal(userId);
            if (null != saleTotal) {
                userData.setSaleTotal(saleTotal);
            }
            list.add(userData);
        }

        //写入数据库
        boolean bool = userDataManger.saveBatchUserData(list);
        if (!bool) {
            return R.ok(1, false);
        }
        return R.ok(0, true);
    }
}
